pub type TextQuery<'w, 's> = SystemParamItem<'w, 's, STextQuery>;Expand description
Type of Query that may be passed to TextStructure::iter.
pub type TextQuery<'w, 's> = SystemParamItem<'w, 's, STextQuery>;Type of Query that may be passed to TextStructure::iter.