pub enum HephaeTextSystems {
ExtractFontAtlases,
LoadFontsToDatabase,
ComputeStructure,
}Expand description
Labels for systems added by Hephae Text.
Variants
ExtractFontAtlases
System in ExtractSchedule that extracts font atlases into the render world.
LoadFontsToDatabase
System in Update that loads bytes sent from FontLoader into a Font and adds them
to the database.
ComputeStructure
System in PostUpdate that computes and marks TextStructure as
changed as necessary, for convenience of systems wishing to listen for change-detection.