Module layout

Defines font layout computation systems.

Structs

FontLayout
Global handle to the font layout, wrapped in a mutex.
FontLayoutInner
Handles computations for font glyphs.

Enums

FontLayoutError
Errors that may arise from font computations.

Functions

load_fonts_to_database
loads bytes sent from FontLoader into a Font and adds them to the database.